==> pegasus-merchandise-api-3.11.12-GS-20250206.045208-1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsSpvVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.pegasus.merchandise.enums.PcsSkuSpecialVarietyEnum;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 *
 * @author gongjun
 * @since 2016-10-13
 */
public class PsSpvVO implements Serializable {

    private Long spvId;
    /**
     * 组合原价
     */
    private BigDecimal originalPrice;
    /**
     * 售价
     */
    private BigDecimal salesPrice;

    /**
     * 折扣价格
     */
//    private BigDecimal discountPrice;

    /**
     * 生日折扣价格
     */
//    private BigDecimal bdDiscountPrice;

    /**
     * PRODUCT ID
     */
    private Long productId;
    /**
     * PRODUCT编码
     */
    private String productCode;
    /**
     * PRODUCT名称
     */
    private String productName;
    /**
     * 成本价
     */
    private BigDecimal costPrice;
    /**
     * 是否组合
     */
    private Boolean combined;

    /**
     * 对应属性值JSON字符串
     */
//    private String attrs;

    /**
     * SPV对应属性值对
     */
    private List<PsAttributeValuePairVO> attributeValuePairList;

    /**
     * SPV对应属性值 [AttrId -> AttrValueId]
     */
//    private Map<Long, Long> attrValues;

    /**
     * 最小起售数
     */
    private Integer minAmount;

    /**
     * 单品SKU CODE
     */
    private String skuCode;

    /**
     * 单品SKU
     */
    private PsSkuVO skuVO;

    /**
     * SKU组合列表
     */
    private List<PsSkuCombinationVO> skuCombinationList;

    /**
     * 预告活动价格
     */
    private BigDecimal advancePrice;
    /**
     * SKU维度活动列表
     */
    private List<PsCampaignVO> campaignList = new ArrayList<>();
    //transient
    private List<EsCampaignVO> esCampaignList = new ArrayList<>();

    /**
     * 预告活动
     */
    private List<PsCampaignVO> advanceCampaignList = new ArrayList<>();
    //transient
    private List<EsCampaignVO> esAdvanceCampaignList = new ArrayList<>();
    /**
     * 价格计算结果
     */
//    private List<PriceCalResultVO> priceCalResults;

    /**
     * 生日折扣价格计算结果
     */
//    private List<PriceCalResultVO> bdPriceCalResults;

    /**
     * SKU库存信息
     */
//    private PsStockVO psStockVO;
//
//    private PsStockVO psFurnitureStockVO;
//
//    private PsPresaleSaleStockVO psPresaleSaleStockVO;

    private Boolean isNewMember = false;//是否是新人专享

    /**
     * 非组合商品后端主类目编号
     */
    private Long categoryId;

    private String bu;

    private Integer customPrintTemplate;//0:不支持 1:吊牌定制
    //transient
//    private String attrValue1;
    //transient
//    private String attrValue2;
    //transient
//    private String attrValue3;
    private String spvImg;

    /**
     * 是否来单
     */
    private Boolean isJit;

    private PcsSkuSpecialVarietyEnum pcsSkuSpecialVarietyEnum;

    public Long getSpvId() {
        return spvId;
    }

    public void setSpvId(Long spvId) {
        this.spvId = spvId;
    }

    public BigDecimal getSalesPrice() {
        return salesPrice;
    }

    public void setSalesPrice(BigDecimal salesPrice) {
        this.salesPrice = salesPrice;
    }

//    public BigDecimal getDiscountPrice() {
//        return discountPrice;
//    }
//
//    public void setDiscountPrice(BigDecimal discountPrice) {
//        this.discountPrice = discountPrice;
//    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }

    public Boolean getCombined() {
        return combined;
    }

    public void setCombined(Boolean combined) {
        this.combined = combined;
    }

//    public String getAttrs() {
//        return attrs;
//    }
//
//    public void setAttrs(String attrs) {
//        this.attrs = attrs;
//    }

    public List<PsAttributeValuePairVO> getAttributeValuePairList() {
        return attributeValuePairList;
    }

    public void setAttributeValuePairList(List<PsAttributeValuePairVO> attributeValuePairList) {
        this.attributeValuePairList = attributeValuePairList;
    }

//    public Map<Long, Long> getAttrValues() {
//        return attrValues;
//    }
//
//    public void setAttrValues(Map<Long, Long> attrValues) {
//        this.attrValues = attrValues;
//    }


    public Integer getMinAmount() {
        return minAmount;
    }

    public void setMinAmount(Integer minAmount) {
        this.minAmount = minAmount;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public PsSkuVO getSkuVO() {
        return skuVO;
    }

    public void setSkuVO(PsSkuVO skuVO) {
        this.skuVO = skuVO;
    }

    public List<PsSkuCombinationVO> getSkuCombinationList() {
        return skuCombinationList;
    }

    public void setSkuCombinationList(List<PsSkuCombinationVO> skuCombinationList) {
        this.skuCombinationList = skuCombinationList;
    }

    public BigDecimal getAdvancePrice() {
        return advancePrice;
    }

    public void setAdvancePrice(BigDecimal advancePrice) {
        this.advancePrice = advancePrice;
    }

    public List<PsCampaignVO> getCampaignList() {
        return campaignList;
    }

    public void setCampaignList(List<PsCampaignVO> campaignList) {
        this.campaignList = campaignList;
    }

    public List<PsCampaignVO> getAdvanceCampaignList() {
        return advanceCampaignList;
    }

    public void setAdvanceCampaignList(List<PsCampaignVO> advanceCampaignList) {
        this.advanceCampaignList = advanceCampaignList;
    }

    public List<EsCampaignVO> getEsCampaignList() {
        return esCampaignList;
    }

    public void setEsCampaignList(List<EsCampaignVO> esCampaignList) {
        this.esCampaignList = esCampaignList;
    }

    public List<EsCampaignVO> getEsAdvanceCampaignList() {
        return esAdvanceCampaignList;
    }

    public void setEsAdvanceCampaignList(List<EsCampaignVO> esAdvanceCampaignList) {
        this.esAdvanceCampaignList = esAdvanceCampaignList;
    }

//    public List<PriceCalResultVO> getPriceCalResults() {
//        return priceCalResults;
//    }
//
//    public void setPriceCalResults(List<PriceCalResultVO> priceCalResults) {
//        this.priceCalResults = priceCalResults;
//    }

//    public List<PriceCalResultVO> getBdPriceCalResults() {
//        return bdPriceCalResults;
//    }
//
//    public void setBdPriceCalResults(List<PriceCalResultVO> bdPriceCalResults) {
//        this.bdPriceCalResults = bdPriceCalResults;
//    }

//    public BigDecimal getBdDiscountPrice() {
//        return bdDiscountPrice;
//    }
//
//    public void setBdDiscountPrice(BigDecimal bdDiscountPrice) {
//        this.bdDiscountPrice = bdDiscountPrice;
//    }

//    public PsStockVO getPsStockVO() {
//        return psStockVO;
//    }
//
//    public void setPsStockVO(PsStockVO psStockVO) {
//        this.psStockVO = psStockVO;
//    }
//
//    public PsPresaleSaleStockVO getPsPresaleSaleStockVO() {
//        return psPresaleSaleStockVO;
//    }
//
//    public void setPsPresaleSaleStockVO(PsPresaleSaleStockVO psPresaleSaleStockVO) {
//        this.psPresaleSaleStockVO = psPresaleSaleStockVO;
//    }
//
//    public PsStockVO getPsFurnitureStockVO() {
//        return psFurnitureStockVO;
//    }
//
//    public void setPsFurnitureStockVO(PsStockVO psFurnitureStockVO) {
//        this.psFurnitureStockVO = psFurnitureStockVO;
//    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public BigDecimal getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(BigDecimal originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Integer getCustomPrintTemplate() {
        return customPrintTemplate;
    }

    public void setCustomPrintTemplate(Integer customPrintTemplate) {
        this.customPrintTemplate = customPrintTemplate;
    }

//    @JsonIgnore
//    public Integer getCanUseQuantity() {
//        Boolean isJit = isJit();
//        if (isJit == null) {
//            throw new RuntimeException("该SPV没包含SKU，不能查SPV可用数量！");
//        };
//        if (isJit) {
//            return Integer.MAX_VALUE - 100;
//        }
//
//        if(combined == null || !combined) {
//            if (psPresaleSaleStockVO != null  && psPresaleSaleStockVO.getAvailQuantity() > 0) {
//                return psPresaleSaleStockVO.getAvailQuantity();
//            }
//        }
//        if(psStockVO != null){
//            return psStockVO.getCanUseQuantity();
//        }
//        return 0;
//    }
    
//    @JsonIgnore
//    public Integer getCanUseQuantityOffLine() {
//        Boolean isJit = isJit();
//        if (isJit == null) {
//            throw new RuntimeException("该SPV没包含SKU，不能查SPV可用数量！");
//        };
//        if (isJit) return Integer.MAX_VALUE - 100;
//        int canUseQuantity = 0;
//        if (psStockVO != null && psStockVO.getCanUseQuantity() != null &&psStockVO.getCanUseQuantity() > 0) {
//        	canUseQuantity += psStockVO.getCanUseQuantity();
//        }
//        if(psFurnitureStockVO != null && psFurnitureStockVO.getCanUseQuantity() != null && psFurnitureStockVO.getCanUseQuantity() > 0){
//        	canUseQuantity += psFurnitureStockVO.getCanUseQuantity();
//        }
//        if (psPresaleSaleStockVO != null && psPresaleSaleStockVO.getAvailQuantity() > 0) {
//        	canUseQuantity += psPresaleSaleStockVO.getAvailQuantity();
//        }
//        return canUseQuantity;
//    }

//    public Boolean isJit() {
//        if (combined) {
//            return false;
//        }
//        if(skuVO == null) {
//            return null;
//        }
//        return skuVO.getIsJit() == 1;
//    }

//    public Boolean getIsNewMember() {
//        if(CollectionUtils.isNotEmpty(esCampaignList)){
//            for(EsCampaignVO campaignVO : esCampaignList){
//                if("01".equals(campaignVO.getMemberType())){
//                    return true;
//                }
//            }
//        }
//        return false;
//    }

    public String getBu() {
        return bu;
    }

    public void setBu(String bu) {
        this.bu = bu;
    }

//    public String getAttrValue1() {
//        return attrValue1;
//    }
//
//    public void setAttrValue1(String attrValue1) {
//        this.attrValue1 = attrValue1;
//    }
//
//    public String getAttrValue2() {
//        return attrValue2;
//    }
//
//    public void setAttrValue2(String attrValue2) {
//        this.attrValue2 = attrValue2;
//    }
//
//    public String getAttrValue3() {
//        return attrValue3;
//    }
//
//    public void setAttrValue3(String attrValue3) {
//        this.attrValue3 = attrValue3;
//    }

    public String getSpvImg() {
        return spvImg;
    }

    public void setSpvImg(String spvImg) {
        this.spvImg = spvImg;
    }

    public Boolean getIsNewMember() {
        return isNewMember;
    }

    public void setIsNewMember(Boolean isNewMember) {
        this.isNewMember = isNewMember;
    }

    public Boolean getIsJit() {
        return isJit;
    }

    public void setIsJit(Boolean isJit) {
        this.isJit = isJit;
    }

    public PcsSkuSpecialVarietyEnum getPcsSkuSpecialVarietyEnum() {
        return pcsSkuSpecialVarietyEnum;
    }

    public void setPcsSkuSpecialVarietyEnum(PcsSkuSpecialVarietyEnum pcsSkuSpecialVarietyEnum) {
        this.pcsSkuSpecialVarietyEnum = pcsSkuSpecialVarietyEnum;
    }
}

==> pegasus-merchandise-api-4.0.9-GS-20250912.071951-1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsSpvVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.pegasus.merchandise.enums.PcsSkuSpecialVarietyEnum;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 *
 * @author gongjun
 * @since 2016-10-13
 */
public class PsSpvVO implements Serializable {

    private Long spvId;
    /**
     * 组合原价
     */
    private BigDecimal originalPrice;
    /**
     * 售价
     */
    private BigDecimal salesPrice;



    /**
     * PRODUCT ID
     */
    private Long productId;
    /**
     * PRODUCT编码
     */
    private String productCode;
    /**
     * PRODUCT名称
     */
    private String productName;
    /**
     * 成本价
     */
    private BigDecimal costPrice;
    /**
     * 是否组合
     */
    private Boolean combined;

    /**
     * 对应属性值JSON字符串
     */
//    private String attrs;

    /**
     * SPV对应属性值对
     */
    private List<PsAttributeValuePairVO> attributeValuePairList;

    /**
     * SPV对应属性值 [AttrId -> AttrValueId]
     */
//    private Map<Long, Long> attrValues;

    /**
     * 最小起售数
     */
    private Integer minAmount;

    /**
     * 单品SKU CODE
     */
    private String skuCode;
    private String barCode;

    /**
     * 单品SKU
     */
    private PsSkuVO skuVO;

    /**
     * SKU组合列表
     */
    private List<PsSkuCombinationVO> skuCombinationList;

    /**
     * 预告活动价格
     */
    private BigDecimal advancePrice;
    /**
     * SKU维度活动列表
     */
    private List<PsCampaignVO> campaignList = new ArrayList<>();
    //transient
    private List<EsCampaignVO> esCampaignList = new ArrayList<>();

    /**
     * 预告活动
     */
    private List<PsCampaignVO> advanceCampaignList = new ArrayList<>();
    //transient
    private List<EsCampaignVO> esAdvanceCampaignList = new ArrayList<>();



    private Boolean isNewMember = false;//是否是新人专享

    /**
     * 非组合商品后端主类目编号
     */
    private Long categoryId;

    private String bu;

    private Integer customPrintTemplate;//0:不支持 1:吊牌定制

    private String spvImg;

    /**
     * 是否来单
     */
    private Boolean isJit;

    private PcsSkuSpecialVarietyEnum pcsSkuSpecialVarietyEnum;

    public Long getSpvId() {
        return spvId;
    }

    public void setSpvId(Long spvId) {
        this.spvId = spvId;
    }

    public BigDecimal getSalesPrice() {
        return salesPrice;
    }

    public void setSalesPrice(BigDecimal salesPrice) {
        this.salesPrice = salesPrice;
    }


    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }

    public Boolean getCombined() {
        return combined;
    }

    public void setCombined(Boolean combined) {
        this.combined = combined;
    }



    public List<PsAttributeValuePairVO> getAttributeValuePairList() {
        return attributeValuePairList;
    }

    public void setAttributeValuePairList(List<PsAttributeValuePairVO> attributeValuePairList) {
        this.attributeValuePairList = attributeValuePairList;
    }



    public Integer getMinAmount() {
        return minAmount;
    }

    public void setMinAmount(Integer minAmount) {
        this.minAmount = minAmount;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getBarCode() {
        return barCode;
    }

    public void setBarCode(String barCode) {
        this.barCode = barCode;
    }

    public PsSkuVO getSkuVO() {
        return skuVO;
    }

    public void setSkuVO(PsSkuVO skuVO) {
        this.skuVO = skuVO;
    }

    public List<PsSkuCombinationVO> getSkuCombinationList() {
        return skuCombinationList;
    }

    public void setSkuCombinationList(List<PsSkuCombinationVO> skuCombinationList) {
        this.skuCombinationList = skuCombinationList;
    }

    public BigDecimal getAdvancePrice() {
        return advancePrice;
    }

    public void setAdvancePrice(BigDecimal advancePrice) {
        this.advancePrice = advancePrice;
    }

    public List<PsCampaignVO> getCampaignList() {
        return campaignList;
    }

    public void setCampaignList(List<PsCampaignVO> campaignList) {
        this.campaignList = campaignList;
    }

    public List<PsCampaignVO> getAdvanceCampaignList() {
        return advanceCampaignList;
    }

    public void setAdvanceCampaignList(List<PsCampaignVO> advanceCampaignList) {
        this.advanceCampaignList = advanceCampaignList;
    }

    public List<EsCampaignVO> getEsCampaignList() {
        return esCampaignList;
    }

    public void setEsCampaignList(List<EsCampaignVO> esCampaignList) {
        this.esCampaignList = esCampaignList;
    }

    public List<EsCampaignVO> getEsAdvanceCampaignList() {
        return esAdvanceCampaignList;
    }

    public void setEsAdvanceCampaignList(List<EsCampaignVO> esAdvanceCampaignList) {
        this.esAdvanceCampaignList = esAdvanceCampaignList;
    }


    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public BigDecimal getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(BigDecimal originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Integer getCustomPrintTemplate() {
        return customPrintTemplate;
    }

    public void setCustomPrintTemplate(Integer customPrintTemplate) {
        this.customPrintTemplate = customPrintTemplate;
    }



    public String getBu() {
        return bu;
    }

    public void setBu(String bu) {
        this.bu = bu;
    }



    public String getSpvImg() {
        return spvImg;
    }

    public void setSpvImg(String spvImg) {
        this.spvImg = spvImg;
    }

    public Boolean getIsNewMember() {
        return isNewMember;
    }

    public void setIsNewMember(Boolean isNewMember) {
        this.isNewMember = isNewMember;
    }

    public Boolean getIsJit() {
        return isJit;
    }

    public void setIsJit(Boolean isJit) {
        this.isJit = isJit;
    }

    public PcsSkuSpecialVarietyEnum getPcsSkuSpecialVarietyEnum() {
        return pcsSkuSpecialVarietyEnum;
    }

    public void setPcsSkuSpecialVarietyEnum(PcsSkuSpecialVarietyEnum pcsSkuSpecialVarietyEnum) {
        this.pcsSkuSpecialVarietyEnum = pcsSkuSpecialVarietyEnum;
    }
}
